#*******************************************************************************
# Script to test VizScorecard
# Eva Rifà Rovira 
#*******************************************************************************
library(kableExtra)
filepath <- "/esarchive/scratch/erifarov/git/esviz/R/"
f <- list.files(filepath)  
ff <- lapply(f, function(x) paste0(filepath, x))  
invisible(lapply(ff,source))
#-------------------------------------------------------------------------------
setwd("/esarchive/scratch/erifarov/rpackages/esviz/scorecard/out_testing")
source("/esarchive/scratch/erifarov/git/esviz/R/VizScorecard.R")
################################################################################
# Tests:
#-----------------------------------------------------
# Tests 1: Minimal use case
#-----------------------------------------------------
set.seed(1)
data <- array(rnorm(1000), dim = c('sdate' = 12, 'metric' = 4, 'region' = 3, 
                                   'time' = 6)) 
VizScorecard(data = data)

################################################################################
#-----------------------------------------------------
# Tests 2: Input parameters
#-----------------------------------------------------
# Test any dimension
set.seed(1)
data <- array(rnorm(1000), dim = c('a' = 12, 'b' = 6, 'c' = 1, 'd' = 1)) 
VizScorecard(data = data, row_dim = 'c', subrow_dim = 'a',
             col_dim = 'd', subcol_dim = 'b', legend_dim = 'c')

# Test any dimension
set.seed(1)
data <- array(rnorm(1000), dim = c('a' = 12, 'b' = 6, 'd' = 1)) 
VizScorecard(data = data, row_dim = 'c', subrow_dim = 'a',
             col_dim = 'd', subcol_dim = 'b', legend_dim = 'c')

# (2.1) Test dim names
set.seed(1)
data <- array(rnorm(1000), dim = c('sdate' = 12, 'metric' = 4, 'region' = 3, 
                                   'time' = 6)) 
VizScorecard(data = data, row_dim = 'time', subrow_dim = 'sdate',
             col_dim = 'region', subcol_dim = 'metric', legend_dim = 'time')

# (2.2) Test structure names
set.seed(1)
data <- array(rnorm(1000), dim = c('sdate' = 12, 'metric' = 4, 'region' = 3, 
                                   'time' = 6)) 
VizScorecard(data = data, row_names = c('a', 'b', 'c'), subrow_names = c('d', 'e', 'f', 'g', 'h', 'i'), col_names = c('j', 'k', 'l', 'm'),
subcol_names = c('n', 'o','p', 'q', 'r','s', 't', 'u', 'v', 'w', 'x', 'y'))

# (2.3) Test titles
set.seed(1)
data <- array(rnorm(1000), dim = c('sdate' = 12, 'metric' = 4, 'region' = 3, 
                                   'time' = 6)) 
VizScorecard(data = data, row_names = c('a', 'b', 'c'), subrow_names = c('d', 'e', 'f', 'g', 'h', 'i'), col_names = c('j', 'k', 'l', 'm'),
subcol_names = c('n', 'o','p', 'q', 'r','s', 't', 'u', 'v', 'w', 'x', 'y'), row_title = "Row title", subrow_title = 'Subrow title', table_title = "Table title", table_subtitle = "Table subtitle")

# (2.4) Test legend breaks and palette
set.seed(1)
data <- array(rnorm(1000), dim = c('sdate' = 12, 'metric' = 4, 'region' = 3, 
                                   'time' = 6)) 
legend_breaks <- seq(-1,1, 0.3)
VizScorecard(data = data, legend_breaks = legend_breaks, 
             palette = ClimColors(6))

# Test lable_scale
set.seed(1)
data <- array(rnorm(1000), dim = c('sdate' = 12, 'metric' = 4, 'region' = 3, 
                                   'time' = 6)) 
VizScorecard(data = data, label_scale = 0.3)

# Test legend width
set.seed(1)
data <- array(rnorm(1000), dim = c('sdate' = 12, 'metric' = 4, 'region' = 3, 
                                   'time' = 6)) 
VizScorecard(data = data, legend_width = 300)
# Test legend height
set.seed(1)
data <- array(rnorm(1000), dim = c('sdate' = 12, 'metric' = 4, 'region' = 3, 
                                   'time' = 6)) 
VizScorecard(data = data, legend_height = 100)
# Test colorunder and colorsup
set.seed(1)
data <- array(rnorm(1000), dim = c('sdate' = 12, 'metric' = 4, 'region' = 3, 
                                   'time' = 6)) 
VizScorecard(data = data, colorunder = 'gray', colorsup = 'yellow')
VizScorecard(data = data)
# Test round decimal
set.seed(1)
data <- array(rnorm(1000), dim = c('sdate' = 12, 'metric' = 4, 'region' = 3, 
                                   'time' = 6)) 
VizScorecard(data = data, round_decimal = 3)
# Test font size
set.seed(1)
data <- array(rnorm(1000), dim = c('sdate' = 12, 'metric' = 4, 'region' = 3, 
                                   'time' = 6)) 
VizScorecard(data = data, font_size = 3)
# Test legend_white_space
set.seed(1)
data <- array(rnorm(1000), dim = c('sdate' = 12, 'metric' = 4, 'region' = 3, 
                                   'time' = 6)) 
VizScorecard(data = data, legend_white_space = 15)
VizScorecard(data = data, legend_white_space = 6)
# Test col1_width and col2_width
set.seed(1)
data <- array(rnorm(1000), dim = c('sdate' = 12, 'metric' = 4, 'region' = 3, 
                                   'time' = 6)) 
VizScorecard(data = data, col1_width = 10, row_names = c('test1_test1', 'test2_test2 tes2 test2', 'test3 test3 test3'), col2_width = 15)
###############################################################################
#-----------------------------------------------------
# Tests 3: Specific cases
#-----------------------------------------------------
# (3.1) Test empty values
# Many values NA
set.seed(1)
data <- array(rnorm(1000), dim = c('sdate' = 12, 'metric' = 4, 'region' = 3, 
                                   'time' = 6)) 
data[, 1, , ] <- NA
VizScorecard(data = data)

# 1 value NA
set.seed(1)
data <- array(rnorm(1000), dim = c('sdate' = 12, 'metric' = 4, 'region' = 3, 
                                   'time' = 6)) 
data[1, 1,1 , 1] <- NA
VizScorecard(data = data)

# All NA
set.seed(1)
data <- array( dim = c('sdate' = 12, 'metric' = 4, 'region' = 3, 
                                   'time' = 6)) 
VizScorecard(data = data)

# 1 value NaN
set.seed(1)
data <- array(rnorm(1000), dim = c('sdate' = 12, 'metric' = 4, 'region' = 3, 
                                   'time' = 6)) 
data[1, 1,1 , 1] <- NaN
VizScorecard(data = data)
################################################################################
#-----------------------------------------------------
# Tests 4: Test sign
#-----------------------------------------------------
source("/esarchive/scratch/erifarov/git/esviz/R/VizScorecard.R")
# sign
set.seed(1)
data <- array(rnorm(1000), dim = c('sdate' = 12, 'metric' = 4, 'region' = 3, 
                                   'time' = 6)) 
vals <- c(rep(T, 200), rep(F, 300), T, F, rep(T, 200), rep(F, 162))
sign <- array(vals, dim = c('sdate' = 12, 'metric' = 4, 'region' = 3, 
                                   'time' = 6)) 
VizScorecard(data = data, sign = sign)

sign <- array(vals, dim = c('metric' = 4, 'time' = 6, 'region' = 3, 
                            'sdate' = 12)) 
VizScorecard(data = data, sign = sign)

################################################################################
#-----------------------------------------------------
# Tests 5: Test example
#-----------------------------------------------------

data <- array(rnorm(1000), dim = c('sdate' = 12, 'metric' = 4, 'region' = 3, 
                                   'time' = 6)) 
row_names <- c('Tropics', 'Extra-tropical NH', 'Extra-tropical SH')
col_names <- c('Mean bias (K)', 'Correlation', 'RPSS','CRPSS')
VizScorecard(data = data, row_names = row_names, col_names = col_names, 
             subcol_names =  month.abb[as.numeric(1:12)],
             row_title = 'Region', subrow_title = 'Forecast Month', 
             col_title = 'Start date', 
             table_title = "Temperature of ECMWF System 5", 
             table_subtitle = "(Ref: ERA5 1994-2016)", 
             fileout = 'test.png')